<?php
/**
 * Defines customizer options
 *
 * @package Customizer Library Demo
 */

function customizer_library_demo_options() {

	// Theme defaults
	$primary_color = '#ce181e';
	$newsletter_bg_color = "";
	$newsletter_btn_color ="#47c2a5";
	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// More Examples
	$section = 'examples';

	// Arrays 

	$layout_choices = array(
		'choice-1' => 'Responsive Layout',
		'choice-2' => 'Fixed Layout'
	);

	$newsletter_position_choices = array(
		'choice-1' => 'Site Header',
		'choice-2' => 'Site Footer'
	);

	$loop_style_choices = array(
		'choice-1' => 'Blog Layout',		
		'choice-2' => 'Grid Layout',
		'choice-3' => 'List Layout',
	);	

	$home_layout_choices = array(
		'choice-1' => 'Recent Posts | Featured Posts | Featured Coupons',		
		'choice-2' => 'Recent Posts | Featured Coupons | Featured Posts',
		'choice-3' => 'Featured Posts | Recent Posts | Featured Coupons',
		'choice-4' => 'Featured Posts | Featured Coupons | Recent Posts',		
		'choice-5' => 'Featured Coupons | Recent Posts | Featured Posts',
		'choice-6' => 'Featured Coupons | Featured Posts | Recent Posts',		
	);		

	$coupon_style_choices = array(
		'choice-1' => 'Hidden and click to reveal',
		'choice-2' => 'Visible for all visitors'
	);

	$sections[] = array(
		'id' => $section,
		'title' => __( 'Theme Settings', 'improve-pro' ),
		'priority' => '10'
	);

	$options['logo'] = array(
		'id' => 'logo',
		'label'   => __( 'Logo', 'improve-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => get_template_directory_uri().'/assets/img/logo.png'
	);

	$options['favicon'] = array(
		'id' => 'favicon',
		'label'   => __( 'Favicon', 'improve-pro' ),
		'section' => $section,
		'type'    => 'image',
		'default' => ''
	);	

	$options['primary-color'] = array(
		'id' => 'primary-color',
		'label'   => __( 'Theme Primary Color', 'improve-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $primary_color // hex
	);

	$options['newsletter-bg-color'] = array(
		'id' => 'newsletter-bg-color',
		'label'   => __( 'Newsletter Background Color', 'improve-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $newsletter_bg_color // hex
	);

	$options['newsletter-btn-color'] = array(
		'id' => 'newsletter-btn-color',
		'label'   => __( 'Newsletter Button Color', 'improve-pro' ),
		'section' => $section,
		'type'    => 'color',
		'default' => $newsletter_btn_color // hex
	);

	$options['primary-font'] = array(
		'id' => 'primary-font',
		'label'   => __( 'Body Font', 'improve-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Open Sans'
	);

	$options['secondary-font'] = array(
		'id' => 'secondary-font',
		'label'   => __( 'Heading Font', 'improve-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => customizer_library_get_font_choices(),
		'default' => 'Open Sans'
	);	

	$options['site-layout'] = array(
		'id' => 'site-layout',
		'label'   => __( 'Site Layout', 'improve-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $layout_choices,
		'default' => 'choice-1'
	);

	$options['sticky-nav-on'] = array(
		'id' => 'sticky-nav-on',
		'label'   => __( 'Sticky header navigation', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => false,
	);			

	$options['header-search-on'] = array(
		'id' => 'header-search-on',
		'label'   => __( 'Display header search form', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['home-layout'] = array(
		'id' => 'home-layout',
		'label'   => __( 'Homepage Layout', 'improve-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $home_layout_choices,
		'default' => 'choice-1'
	);

	$options['newsletter-position'] = array(
		'id' => 'newsletter-position',
		'label'   => __( 'Home Newsletter Position', 'improve-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $newsletter_position_choices,
		'default' => 'choice-1'
	);

	$options['loop-style'] = array(
		'id' => 'loop-style',
		'label'   => __( 'Latest Posts Style', 'improve-pro' ),
		'section' => $section,
		'type'    => 'select',
		'choices' => $loop_style_choices,
		'default' => 'choice-1'
	);	

	$options['entry-excerpt-length'] = array(
		'id' => 'entry-excerpt-length',
		'label'   => __( 'Number of words to show on excerpt', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '45',		
	);
	
	$options['featured-content-on'] = array(
		'id' => 'featured-content-on',
		'label'   => __( 'Display featured content on homepage', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['featured-content-heading'] = array(
		'id' => 'featured-content-heading',
		'label'   => __( 'Featured content section heading', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'Featured News',		
	);

	$options['featured-num'] = array(
		'id' => 'featured-num',
		'label'   => __( 'Number of featured posts to show', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '4',		
	);

	$options['featured-content-url'] = array(
		'id' => 'featured-content-url',
		'label'   => __( 'Featured content page URL', 'improve-pro' ),
		'section' => $section,
		'type'    => 'url',
		'default' => home_url() . '/featured-news',
	);	

	$options['featured-coupon-on'] = array(
		'id' => 'featured-coupon-on',
		'label'   => __( 'Display featured coupons on homepage', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['featured-coupons-heading'] = array(
		'id' => 'featured-coupons-heading',
		'label'   => __( 'Featured coupons section heading', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => 'Featured Deals & Coupon Codes',		
	);

	$options['featured-coupons-num'] = array(
		'id' => 'featured-coupons-num',
		'label'   => __( 'Number of featured coupons to show', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '3'
	);			

	$options['coupons-page-desc'] = array(
		'id' => 'coupons-page-desc',
		'label'   => __( 'Coupons page description', 'improve-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => 'You may enter description for the coupon page here.',		
	);

	$options['coupon-style'] = array(
		'id' => 'coupon-style',
		'label'   => __( 'How coupons displayed on single coupon page', 'improve-pro' ),
		'section' => $section,
		'type'    => 'radio',
		'choices' => $coupon_style_choices,
		'default' => 'choice-1'
	);			

	$options['single-breadcrumbs-on'] = array(
		'id' => 'single-breadcrumbs-on',
		'label'   => __( 'Display breadcrumbs on single posts', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['single-share-on'] = array(
		'id' => 'single-share-on',
		'label'   => __( 'Display share icons on single posts', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['single-featured-on'] = array(
		'id' => 'single-featured-on',
		'label'   => __( 'Display featured image on single posts', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => true,
	);	

	$options['author-box-on'] = array(
		'id' => 'author-box-on',
		'label'   => __( 'Display author box on single posts', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	
	$options['related-posts-on'] = array(
		'id' => 'related-posts-on',
		'label'   => __( 'Display related posts on single posts', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['footer-widgets-on'] = array(
		'id' => 'footer-widgets-on',
		'label'   => __( 'Display footer widgets', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);

	$options['back-top-on'] = array(
		'id' => 'back-top-on',
		'label'   => __( 'Display "back to top" icon link on the site bottom', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['header-social-on'] = array(
		'id' => 'header-social-on',
		'label'   => __( 'Display social icons on site header', 'improve-pro' ),
		'section' => $section,
		'type'    => 'checkbox',
		'default' => 1,
	);	

	$options['facebook-url'] = array(
		'id' => 'facebook-url',
		'label'   => __( 'Your Facebook URL', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);

	$options['twitter-url'] = array(
		'id' => 'twitter-url',
		'label'   => __( 'Your Twitter URL', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['google-plus-url'] = array(
		'id' => 'google-plus-url',
		'label'   => __( 'Your Google+ URL', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['youtube-url'] = array(
		'id' => 'youtube-url',
		'label'   => __( 'Your YouTube URL', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['instagram-url'] = array(
		'id' => 'instagram-url',
		'label'   => __( 'Your Instagram URL', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['pinterest-url'] = array(
		'id' => 'pinterest-url',
		'label'   => __( 'Your Pinterest URL', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);	

	$options['rss-url'] = array(
		'id' => 'rss-url',
		'label'   => __( 'Your RSS feed URL', 'improve-pro' ),
		'section' => $section,
		'type'    => 'text',
		'default' => '',		
	);		

	$options['footer-credit'] = array(
		'id' => 'footer-credit',
		'label'   => __( 'Customize Site Footer Text/Link', 'improve-pro' ),
		'section' => $section,
		'type'    => 'textarea',
		'default' => '&copy; ' . date("o") . ' <a href="' . home_url() .'">' . get_bloginfo('name') . '</a> - Theme by <a href="https://www.happythemes.com" target="_blank">HappyThemes</a>'
	);			

	//$options['example-range'] = array(
	//	'id' => 'example-range',
	//	'label'   => __( 'Example Range Input', 'improve-pro' ),
	//	'section' => $section,
	//	'type'    => 'range',
	//	'input_attrs' => array(
	//      'min'   => 0,
	//        'max'   => 10,
	//        'step'  => 1,
	//       'style' => 'color: #0a0',
	//	)
	//);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

	// To delete custom mods use: customizer_library_remove_theme_mods();

}
add_action( 'init', 'customizer_library_demo_options' );